==> backup-9.23.2025_13-36-35_ayntair.tar.gz: backup-9.23.2025_13-36-35_ayntair/mysql.sql <==
-- cPanel mysql backup
GRANT USAGE ON *.* TO 'ayntair'@'45.90.73.208' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT USAGE ON *.* TO 'ayntair'@'lavaggbo.com.vn' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair'@'lavaggbo.com.vn';
GRANT USAGE ON *.* TO 'ayntair'@'localhost' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair'@'localhost';
GRANT USAGE ON *.* TO 'ayntair'@'s4.mizbandp.com' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'45.90.73.208' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE, EVENT, TRIGGER ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'45.90.73.208';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'lavaggbo.com.vn' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE, EVENT, TRIGGER ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'lavaggbo.com.vn';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'localhost' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE, EVENT, TRIGGER ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'localhost';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'s4.mizbandp.com' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE, EVENT, TRIGGER ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'s4.mizbandp.com';

==> backup-12.18.2024_07-52-32_ayntair.tar.gz: backup-12.18.2024_07-52-32_ayntair/mysql.sql <==
-- cPanel mysql backup
GRANT USAGE ON *.* TO 'ayntair'@'45.90.73.208' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair'@'45.90.73.208';
GRANT USAGE ON *.* TO 'ayntair'@'lavaggbo.com.vn' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair'@'lavaggbo.com.vn';
GRANT USAGE ON *.* TO 'ayntair'@'localhost' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair'@'localhost';
GRANT USAGE ON *.* TO 'ayntair'@'s4.mizbandp.com' IDENTIFIED BY PASSWORD '*EB5F839E3BB28BDAD054D8D4C7C88F4FD044C7BB';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair'@'s4.mizbandp.com';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'45.90.73.208' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'45.90.73.208';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'lavaggbo.com.vn' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'lavaggbo.com.vn';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'localhost' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'localhost';
GRANT USAGE ON *.* TO 'ayntair_whmcs'@'s4.mizbandp.com' IDENTIFIED BY PASSWORD '*4F18D13769495FD3CBF065B4C420302EED4E6928';
GRANT ALL PRIVILEGES ON `ayntair\_whmcs`.* TO 'ayntair_whmcs'@'s4.mizbandp.com';
